==> dl.php?src=linea21_1_4.zip: linea21/languages/fr/installer.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author Simon Georget <simon@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$lang = array(

'direction' => 'ltr',
'charset' => 'UTF-8',

# Global
'G-01' => "Installation de Linea21 - version ". LINEA_VERSION. "",
'G-02' => "Etapes (4)",
'G-03' => "Choix de la langue (1/4)",
'G-04' => "Configuration de la base de données (2/4)",
'G-05' => "Création du fichier de configuration (3/4)",
'G-06' => "Fin (4/4)",

# Errors
'L-01' => "Le processus d'installation est verrouillé! Si vous souhaitez continuer, veuillez supprimer le fichier installer.lock",
'L-02' => "Vous devez passer un tableau d'options tà la méthode dbTables",
'L-03' => "Veuillez remplir les champs requis.",
'L-04' => "Connexion à la base de données impossible. Veuillez revoir les paramétres.",
'L-05' => "Sélection de la base de données impossible.",
'L-06' => "Création de la base de données <b>%s</b> impossible.  Erreur : %s",
'L-07' => "Le fichier database.php est introuvable dans %s",
'L-08' => "Erreur durant l'exécution d'une requête SQL. Erreur retournée : %s",
'L-09' => "Exécution des requêtes SQL : <b>%s</b> requêtes ont été exécutées. <b>%s</b> ont échoué. %s",
'L-10' => "Le fichier de configuration a été créé avec succès.",
'L-11' => "Le template <b>%s</b> est introuvable dans %s",

# Other
'I-01' => "Installation de Linea21 - Bienvenue",
'I-02' => "Choisissez la langue d'installation.",
'I-03' => ">> Continuer",
'I-04' => "Configuration de la connexion à la base de données",
'I-05' => "Nom de la base",
'I-06' => "Utilisateur",
'I-07' => "Mot de passe",
'I-08' => "Serveur hôte",
'I-09' => "Créer la base si elle n'existe pas?",
'I-10' => "Oui",
'I-11' => "Non",
'I-12' => "Erreur!",
'I-13' => "Revenez à l'<a href=\"javascript:history.go(-1)\">étape précédente</a> et assurez vous que les informations soient correctes.",
'I-14' => "<h4>Erreurs détectées :</h4><br /> %s",
'I-15' => "Création de la base de données",
'I-16' => "Ignorer et continuer...",
'I-17' => "Paramétrage du fichier de configuration",
'I-18' => "Adresse racine du site",
'I-19' => "Chemin physique de l'application",
'I-20' => "Terminer",

'I-21' => "Installation terminée",
'I-22' => "L'installation est terminée.",
'I-23' => "-- Choisir votre langue --",
'I-24' => "Installation de <a href=\"".SITE_LINEA_URL ."\">Linea21</a> - version ". LINEA_VERSION. "",


'l21-01' => "Type de la base",
'l21-02' => "Pour MySQL seulement! Si vous utilisez PostgreSQL, la base de données choisie doit préalablement exister.",
'l21-03' => "Les données d'entrée de l'application seront écrites dans la langue séléctionnée!",
'l21-04' => "Un module de configuration avancée sera disponible après installation (depuis l'interface d'administration).",
'l21-05' => "Ne changez pas les valeurs ci-dessous à moins de savoir précisement ce que vous faites.",
'l21-06' => "Nom du site (ex: <em>". SITE_NAME . "</em>)",
'l21-07' => "Email (ex: <em>". MAIL_FROM . "</em>)",
'l21-08' => "Nom associé à l'email (ex: <em>". MAIL_FROMNAME . "</em>)",
'l21-09' => "Accéder à l'<a href=\"../admin/\">interface d'administration</a>.",
'l21-10' => "Login/mot de passe : <strong>admin/linea</strong><br />Veuillez changer le mode de passe par défaut!"
);

==> dl.php?src=linea21_1_6.zip: linea21/languages/fr/installer.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author Simon Georget <simon@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

$lang = array(

'direction' => 'ltr',
'charset' => 'UTF-8',

# Global
'G-01' => "Installation de Linea21 - version ". LINEA_VERSION. "",
'G-02' => "Etapes (4)",
'G-03' => "Choix de la langue (1/4)",
'G-04' => "Configuration de la base de données (2/4)",
'G-05' => "Création du fichier de configuration (3/4)",
'G-06' => "Fin (4/4)",

# Errors
'L-01' => "Le processus d'installation est verrouillé! Si vous souhaitez continuer, veuillez supprimer le fichier installer.lock",
'L-02' => "Vous devez passer un tableau d'options tà la méthode dbTables",
'L-03' => "Veuillez remplir les champs requis.",
'L-04' => "Connexion à la base de données impossible. Veuillez revoir les paramétres.",
'L-05' => "Sélection de la base de données impossible.",
'L-06' => "Création de la base de données <b>%s</b> impossible.  Erreur : %s",
'L-07' => "Le fichier database.php est introuvable dans %s",
'L-08' => "Erreur durant l'exécution d'une requête SQL. Erreur retournée : %s",
'L-09' => "Exécution des requêtes SQL : <b>%s</b> requêtes ont été exécutées. <b>%s</b> ont échoué. %s",
'L-10' => "Le fichier de configuration a été créé avec succès.",
'L-11' => "Le template <b>%s</b> est introuvable dans %s",
'L-12' => "L'écriture des fichiers de configuration est impossible. <br />Veuillez réviser les permissions sur le dossier <code>./config/</code>.",
'L-13' => "L'écriture des fichiers est impossible dans le répertoire d'installation. <br />Veuillez réviser les permissions sur le dossier <code>./install/</code>.",

# Other
'I-01' => "Installation de Linea21 - Bienvenue",
'I-02' => "Choisissez la langue d'installation.",
'I-03' => ">> Continuer",
'I-04' => "Configuration de la connexion à la base de données",
'I-05' => "Nom de la base",
'I-06' => "Utilisateur",
'I-07' => "Mot de passe",
'I-08' => "Serveur hôte",
'I-09' => "Créer la base si elle n'existe pas?",
'I-10' => "Oui",
'I-11' => "Non",
'I-12' => "Erreur!",
'I-13' => "Revenez à l'<a href=\"javascript:history.go(-1)\">étape précédente</a> et assurez vous que les informations soient correctes.",
'I-14' => "<h4>Erreurs détectées :</h4><br /> %s",
'I-15' => "Création de la base de données",
'I-16' => "Ignorer et continuer...",
'I-17' => "Paramétrage du fichier de configuration",
'I-18' => "Adresse racine du site",
'I-19' => "Chemin physique de l'application",
'I-20' => "Terminer",

'I-21' => "Installation terminée",
'I-22' => "L'installation est terminée. Pour plus de sécurité, effacez le dossiser d'installation (<code>/install/</code>).",
'I-23' => "-- Choisir votre langue --",
'I-24' => "Installation de <a href=\"".SITE_LINEA_URL ."\">Linea21</a> - version ". LINEA_VERSION. "",


'l21-01' => "Type de la base",
'l21-02' => "Pour MySQL seulement! Si vous utilisez PostgreSQL, la base de données choisie doit préalablement exister.",
'l21-03' => "Les données d'entrée de l'application seront écrites dans la langue séléctionnée!",
'l21-04' => "Un module de configuration avancée sera disponible après installation (depuis l'interface d'administration).",
'l21-05' => "Ne changez pas les valeurs ci-dessous à moins de savoir précisement ce que vous faites.",
'l21-06' => "Nom du site (ex: <em>". SITE_NAME . "</em>)",
'l21-07' => "Email (ex: <em>". MAIL_FROM . "</em>)",
'l21-08' => "Nom associé à l'email (ex: <em>". MAIL_FROMNAME . "</em>)",
'l21-09' => "Accéder à l'<a href=\"../admin/\">interface d'administration</a>.",
'l21-10' => "Login/mot de passe : <strong>admin/linea</strong><br />Veuillez changer le mode de passe par défaut!",
'l21-11' => "Il est fortement déconseillé d'utiliser PostgreSQL qui ne sera plus implémentée dans la prochaine version de Linea21."
);
